@@ -34,21 +34,21 @@ class Parser : public xmlpp::SaxParser
 {
 public:
   Parser(xmlpp::Document& document);
-  ~Parser() override;
+  virtual ~Parser();
 
 protected:
   // SAX parser callbacks
-  void on_start_document() override {};
-  void on_end_document() override {};
+  void on_start_document() {};
+  void on_end_document() {};
   void on_start_element(const Glib::ustring& name,
-                                const AttributeList& properties) override;
-  void on_end_element(const Glib::ustring& name) override;
-  void on_characters(const Glib::ustring& characters) override;
-  void on_comment(const Glib::ustring& text) override;
-  void on_warning(const Glib::ustring& text) override;
-  void on_error(const Glib::ustring& text) override;
-  void on_fatal_error(const Glib::ustring& text) override;
-  void on_cdata_block(const Glib::ustring& text) override;
+                                const AttributeList& properties);
+  void on_end_element(const Glib::ustring& name);
+  void on_characters(const Glib::ustring& characters);
+  void on_comment(const Glib::ustring& text);
+  void on_warning(const Glib::ustring& text);
+  void on_error(const Glib::ustring& text);
+  void on_fatal_error(const Glib::ustring& text);
+  void on_cdata_block(const Glib::ustring& text);
 
 private:
   // context is a stack to keep track of parent node while the SAX parser
